#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2

# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-08-05
# File  : vzlogger.py
#
# https://wiki.volkszaehler.org/software/controller/vzlogger
#
# 2023-08-05: initial release

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    ValueSpec,
    Integer,
    FixedValue,
)

from cmk.gui.plugins.wato.utils import (
    HostRulespec,
    rulespec_registry,
)
from cmk.gui.plugins.wato.special_agents.common import RulespecGroupDatasourceProgramsApps


def _valuespec_special_agent_vzlogger() -> ValueSpec:
    return Dictionary(
        title=_("vzlogger"),
        elements=[
            ('port', Integer(title=_('Port'), default_value=8081, minvalue=1, maxvalue=65565)),
            ('timeout', Integer(title=_('Connection timeout'), default_value=5, minvalue=1, maxvalue=59)),
            ('use_ip_address', FixedValue(True, title=_('Use IP-Address instead of hostname'), totext='')),
            ('testing', FixedValue(True, title=_('Use test data only'), totext='')),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupDatasourceProgramsApps,
        name="special_agents:vzlogger",
        valuespec=_valuespec_special_agent_vzlogger,
    )
)
