#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2

# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-08-05
# File  : vzlogger.py
#
# https://wiki.volkszaehler.org/software/controller/vzlogger

# 2023-08-05: initial release
# 2024-06-16: modified imports for CMK 2.3

from collections.abc import Sequence
import argparse
import json
import requests

from cmk.special_agents.v0_unstable.agent_common import special_agent_main
from cmk.special_agents.v0_unstable.argument_parsing import Args, create_default_argument_parser

_data = {
    "version": "0.8.1",
    "generator": "vzlogger",
    "data": [
        {
            "uuid": "101670",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    273.31
                ]
            ]
        },
        {
            "uuid": "103670",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    144.36
                ]
            ]
        },
        {
            "uuid": "105670",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    11.1
                ]
            ]
        },
        {
            "uuid": "107670",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    117.84
                ]
            ]
        },
        {
            "uuid": "10180",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    17199974.934100002
                ]
            ]
        },
        {
            "uuid": "10280",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    88550.9837
                ]
            ]
        },
        {
            "uuid": "103270",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    235.20000000000002
                ]
            ]
        },
        {
            "uuid": "105270",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    235
                ]
            ]
        },
        {
            "uuid": "107270",
            "last": 1690921720649,
            "interval": -1,
            "protocol": "sml",
            "tuples": [
                [
                    1690921720649,
                    235.20000000000002
                ]
            ]
        }
    ]
}


def parse_arguments(argv: Sequence[str] | None) -> argparse.Namespace:
    parser = create_default_argument_parser(description=__doc__)
    parser.add_argument('hostname', type=str)
    parser.add_argument('--port', type=int, default=8081)
    parser.add_argument('--timeout', type=int, default=5)
    parser.add_argument('--testing', const=True, required=False, action='store_const')
    # parser.add_argument('--proxy', type=str)
    return parser.parse_args(argv)


def agent_vzlogger_main(args: Args) -> int:  # , retrurn=None
    _vars = vars(args)

    if _vars['testing']:
        data = _data
    else:
        try:
            response = requests.get(f'http://{_vars["hostname"]}:{_vars["port"]}/', timeout=_vars['timeout'])
            response.raise_for_status()
        except (requests.exceptions.RequestException, requests.exceptions.HTTPError) as e:
            print('Error retrieving data:', e)
            exit()
        else:
            data = response.json()

    print('<<<vzlogger:sep(0)>>>')
    print(json.dumps(data))
    return 0


def main() -> int:
    return special_agent_main(parse_arguments, agent_vzlogger_main)
